class ExternalSharingSiteOption:
    def __init__(self):
        pass

    View = "View"
    Edit = "Edit"
    Owner = "Owner"
